==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/BaseImageTriggerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.BaseImageTriggerArgs.builder
import com.pulumi.azurenative.containerregistry.kotlin.enums.BaseImageTriggerType
import com.pulumi.azurenative.containerregistry.kotlin.enums.TriggerStatus
import com.pulumi.azurenative.containerregistry.kotlin.enums.UpdateTriggerPayloadType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The trigger based on base image dependency.
 * @property baseImageTriggerType The type of the auto trigger for base image dependency updates.
 * @property name The name of the trigger.
 * @property status The current status of trigger.
 * @property updateTriggerEndpoint The endpoint URL for receiving update triggers.
 * @property updateTriggerPayloadType Type of Payload body for Base image update triggers.
 */
public data class BaseImageTriggerArgs(
    public val baseImageTriggerType: Output<Either<String, BaseImageTriggerType>>,
    public val name: Output<String>,
    public val status: Output<Either<String, TriggerStatus>>? = null,
    public val updateTriggerEndpoint: Output<String>? = null,
    public val updateTriggerPayloadType: Output<Either<String, UpdateTriggerPayloadType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.BaseImageTriggerArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.BaseImageTriggerArgs =
        com.pulumi.azurenative.containerregistry.inputs.BaseImageTriggerArgs.builder()
            .baseImageTriggerType(
                baseImageTriggerType.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .name(name.applyValue({ args0 -> args0 }))
            .status(
                status?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .updateTriggerEndpoint(updateTriggerEndpoint?.applyValue({ args0 -> args0 }))
            .updateTriggerPayloadType(
                updateTriggerPayloadType?.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [BaseImageTriggerArgs].
 */
@PulumiTagMarker
public class BaseImageTriggerArgsBuilder internal constructor() {
    private var baseImageTriggerType: Output<Either<String, BaseImageTriggerType>>? = null

    private var name: Output<String>? = null

    private var status: Output<Either<String, TriggerStatus>>? = null

    private var updateTriggerEndpoint: Output<String>? = null

    private var updateTriggerPayloadType: Output<Either<String, UpdateTriggerPayloadType>>? = null

    /**
     * @param value The type of the auto trigger for base image dependency updates.
     */
    @JvmName("cchcbvhayeqjoone")
    public suspend fun baseImageTriggerType(`value`: Output<Either<String, BaseImageTriggerType>>) {
        this.baseImageTriggerType = value
    }

    /**
     * @param value The name of the trigger.
     */
    @JvmName("gscwuebpfgfpdmen")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The current status of trigger.
     */
    @JvmName("hejrxkfkajiguhxk")
    public suspend fun status(`value`: Output<Either<String, TriggerStatus>>) {
        this.status = value
    }

    /**
     * @param value The endpoint URL for receiving update triggers.
     */
    @JvmName("ldaweettnfnauprb")
    public suspend fun updateTriggerEndpoint(`value`: Output<String>) {
        this.updateTriggerEndpoint = value
    }

    /**
     * @param value Type of Payload body for Base image update triggers.
     */
    @JvmName("yvaisyoevrpsifkc")
    public suspend
    fun updateTriggerPayloadType(`value`: Output<Either<String, UpdateTriggerPayloadType>>) {
        this.updateTriggerPayloadType = value
    }

    /**
     * @param value The type of the auto trigger for base image dependency updates.
     */
    @JvmName("ivogxahfigvruxoj")
    public suspend fun baseImageTriggerType(`value`: Either<String, BaseImageTriggerType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.baseImageTriggerType = mapped
    }

    /**
     * @param value The type of the auto trigger for base image dependency updates.
     */
    @JvmName("wiopeuadwbwevbnm")
    public fun baseImageTriggerType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, BaseImageTriggerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.baseImageTriggerType = mapped
    }

    /**
     * @param value The type of the auto trigger for base image dependency updates.
     */
    @JvmName("cohkiqtlottcojqw")
    public fun baseImageTriggerType(`value`: BaseImageTriggerType) {
        val toBeMapped = Either.ofRight<String, BaseImageTriggerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.baseImageTriggerType = mapped
    }

    /**
     * @param value The name of the trigger.
     */
    @JvmName("rpydnalmidygcmga")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The current status of trigger.
     */
    @JvmName("fygukelpmomcjreq")
    public suspend fun status(`value`: Either<String, TriggerStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value The current status of trigger.
     */
    @JvmName("ibrgwqvayhdthetj")
    public fun status(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TriggerStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value The current status of trigger.
     */
    @JvmName("unjkwlakeeterppx")
    public fun status(`value`: TriggerStatus) {
        val toBeMapped = Either.ofRight<String, TriggerStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value The endpoint URL for receiving update triggers.
     */
    @JvmName("qaryhwtfpaeaheqk")
    public suspend fun updateTriggerEndpoint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.updateTriggerEndpoint = mapped
    }

    /**
     * @param value Type of Payload body for Base image update triggers.
     */
    @JvmName("ivkwhxarvycbxjdf")
    public suspend fun updateTriggerPayloadType(`value`: Either<String, UpdateTriggerPayloadType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.updateTriggerPayloadType = mapped
    }

    /**
     * @param value Type of Payload body for Base image update triggers.
     */
    @JvmName("lrnljrxcldhafaqp")
    public fun updateTriggerPayloadType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, UpdateTriggerPayloadType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.updateTriggerPayloadType = mapped
    }

    /**
     * @param value Type of Payload body for Base image update triggers.
     */
    @JvmName("xcxldurfnrkuxkov")
    public fun updateTriggerPayloadType(`value`: UpdateTriggerPayloadType) {
        val toBeMapped = Either.ofRight<String, UpdateTriggerPayloadType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.updateTriggerPayloadType = mapped
    }

    internal fun build(): BaseImageTriggerArgs = BaseImageTriggerArgs(
        baseImageTriggerType = baseImageTriggerType ?: throw
            PulumiNullFieldException("baseImageTriggerType"),
        name = name ?: throw PulumiNullFieldException("name"),
        status = status,
        updateTriggerEndpoint = updateTriggerEndpoint,
        updateTriggerPayloadType = updateTriggerPayloadType,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/BaseImageTriggerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.BaseImageTriggerArgs.builder
import com.pulumi.azurenative.containerregistry.kotlin.enums.BaseImageTriggerType
import com.pulumi.azurenative.containerregistry.kotlin.enums.TriggerStatus
import com.pulumi.azurenative.containerregistry.kotlin.enums.UpdateTriggerPayloadType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The trigger based on base image dependency.
 * @property baseImageTriggerType The type of the auto trigger for base image dependency updates.
 * @property name The name of the trigger.
 * @property status The current status of trigger.
 * @property updateTriggerEndpoint The endpoint URL for receiving update triggers.
 * @property updateTriggerPayloadType Type of Payload body for Base image update triggers.
 */
public data class BaseImageTriggerArgs(
    public val baseImageTriggerType: Output<Either<String, BaseImageTriggerType>>,
    public val name: Output<String>,
    public val status: Output<Either<String, TriggerStatus>>? = null,
    public val updateTriggerEndpoint: Output<String>? = null,
    public val updateTriggerPayloadType: Output<Either<String, UpdateTriggerPayloadType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.BaseImageTriggerArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.BaseImageTriggerArgs =
        com.pulumi.azurenative.containerregistry.inputs.BaseImageTriggerArgs.builder()
            .baseImageTriggerType(
                baseImageTriggerType.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .name(name.applyValue({ args0 -> args0 }))
            .status(
                status?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .updateTriggerEndpoint(updateTriggerEndpoint?.applyValue({ args0 -> args0 }))
            .updateTriggerPayloadType(
                updateTriggerPayloadType?.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [BaseImageTriggerArgs].
 */
@PulumiTagMarker
public class BaseImageTriggerArgsBuilder internal constructor() {
    private var baseImageTriggerType: Output<Either<String, BaseImageTriggerType>>? = null

    private var name: Output<String>? = null

    private var status: Output<Either<String, TriggerStatus>>? = null

    private var updateTriggerEndpoint: Output<String>? = null

    private var updateTriggerPayloadType: Output<Either<String, UpdateTriggerPayloadType>>? = null

    /**
     * @param value The type of the auto trigger for base image dependency updates.
     */
    @JvmName("tgwvwlfqtyghaqby")
    public suspend fun baseImageTriggerType(`value`: Output<Either<String, BaseImageTriggerType>>) {
        this.baseImageTriggerType = value
    }

    /**
     * @param value The name of the trigger.
     */
    @JvmName("prclvpjqwqtmidwh")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The current status of trigger.
     */
    @JvmName("kxtgelpwfiqjugym")
    public suspend fun status(`value`: Output<Either<String, TriggerStatus>>) {
        this.status = value
    }

    /**
     * @param value The endpoint URL for receiving update triggers.
     */
    @JvmName("jaagdwyacbkkvnoy")
    public suspend fun updateTriggerEndpoint(`value`: Output<String>) {
        this.updateTriggerEndpoint = value
    }

    /**
     * @param value Type of Payload body for Base image update triggers.
     */
    @JvmName("qccmjwyyykqotiib")
    public suspend
    fun updateTriggerPayloadType(`value`: Output<Either<String, UpdateTriggerPayloadType>>) {
        this.updateTriggerPayloadType = value
    }

    /**
     * @param value The type of the auto trigger for base image dependency updates.
     */
    @JvmName("phyqgdovckscoqnb")
    public suspend fun baseImageTriggerType(`value`: Either<String, BaseImageTriggerType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.baseImageTriggerType = mapped
    }

    /**
     * @param value The type of the auto trigger for base image dependency updates.
     */
    @JvmName("wfqhcqrmckdkkgqb")
    public fun baseImageTriggerType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, BaseImageTriggerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.baseImageTriggerType = mapped
    }

    /**
     * @param value The type of the auto trigger for base image dependency updates.
     */
    @JvmName("ihfbsbnrmkyfyppa")
    public fun baseImageTriggerType(`value`: BaseImageTriggerType) {
        val toBeMapped = Either.ofRight<String, BaseImageTriggerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.baseImageTriggerType = mapped
    }

    /**
     * @param value The name of the trigger.
     */
    @JvmName("csyooaihivvwpysm")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The current status of trigger.
     */
    @JvmName("iguroilolnukugkw")
    public suspend fun status(`value`: Either<String, TriggerStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value The current status of trigger.
     */
    @JvmName("ohlmeshxcsfjmrtc")
    public fun status(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TriggerStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value The current status of trigger.
     */
    @JvmName("cpibstsreuotqrbn")
    public fun status(`value`: TriggerStatus) {
        val toBeMapped = Either.ofRight<String, TriggerStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value The endpoint URL for receiving update triggers.
     */
    @JvmName("qppojjceooabhjgo")
    public suspend fun updateTriggerEndpoint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.updateTriggerEndpoint = mapped
    }

    /**
     * @param value Type of Payload body for Base image update triggers.
     */
    @JvmName("kuymvqvhhsummvxc")
    public suspend fun updateTriggerPayloadType(`value`: Either<String, UpdateTriggerPayloadType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.updateTriggerPayloadType = mapped
    }

    /**
     * @param value Type of Payload body for Base image update triggers.
     */
    @JvmName("rasbafuayndacfff")
    public fun updateTriggerPayloadType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, UpdateTriggerPayloadType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.updateTriggerPayloadType = mapped
    }

    /**
     * @param value Type of Payload body for Base image update triggers.
     */
    @JvmName("degthtrgsuajqqhm")
    public fun updateTriggerPayloadType(`value`: UpdateTriggerPayloadType) {
        val toBeMapped = Either.ofRight<String, UpdateTriggerPayloadType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.updateTriggerPayloadType = mapped
    }

    internal fun build(): BaseImageTriggerArgs = BaseImageTriggerArgs(
        baseImageTriggerType = baseImageTriggerType ?: throw
            PulumiNullFieldException("baseImageTriggerType"),
        name = name ?: throw PulumiNullFieldException("name"),
        status = status,
        updateTriggerEndpoint = updateTriggerEndpoint,
        updateTriggerPayloadType = updateTriggerPayloadType,
    )
}
